summaryrefslogtreecommitdiffstats
path: root/configure.py
diff options
context:
space:
mode:
Diffstat (limited to 'configure.py')
-rw-r--r--configure.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/configure.py b/configure.py
index e991a85..cde42eb 100644
--- a/configure.py
+++ b/configure.py
@@ -121,7 +121,7 @@ def usage(rcode = 2):
sys.stdout.write(" -q dir the root directory of the TQt installation [default %s]\n" % def_qt_dir)
sys.stdout.write(" -r generate code with tracing enabled [default disabled]\n")
sys.stdout.write(" -s TQScintilla is a static library and not a DLL (Windows only)\n")
- sys.stdout.write(" -u build with debugging symbols (retquires a debug build of Python on Windows\n")
+ sys.stdout.write(" -u build with debugging symbols (requires a debug build of Python on Windows\n")
sys.stdout.write(" -v dir where the PyTQt .sip files will be installed [default %s]\n" % opt_pyqtsipdir)
sys.stdout.write(" -w don't suppress compiler output during configuration\n")
sys.stdout.write(" -y lib explicitly specify the type of TQt library, either qt, qt-mt, qte, qte-mt, qtmt, tqt, tqt-mt, tqte, tqte-mt or tqtmt\n")
@@ -665,7 +665,7 @@ def create_features_file(name):
name is the name of the features file in the current directory.
"""
# The features that a given TQt configuration may or may not support. Note
# that STYLE_WINDOWSXP and ASSISTANTCLIENT retquire special handling.
flist = ["ACTION", "CLIPBOARD", "CODECS", "COLORDIALOG", "DATASTREAM",
"DIAL", "DNS", "DOM", "DRAGANDDROP", "ICONVIEW", "IMAGE_TEXT",
"INPUTDIALOG", "FILEDIALOG", "FONTDATABASE", "FONTDIALOG",
@@ -1114,16 +1114,16 @@ def check_qt_installation(macros):
# Early versions of TQt for the Mac didn't include everything. Rather than
# maintain these in the future we just mandate a later version.
if sys.platform == "darwin" and qt_version < 0x030100:
- sipconfig.error("PyTQt for MacOS/X retquires TQt v3.1.0 or later.")
+ sipconfig.error("PyTQt for MacOS/X requires TQt v3.1.0 or later.")
# The way SIP v4.2 and later handle connections between signals and Python
# slots only works with TQt v3 and later. Therefore TQt v2 and earlier needs
# SIP v3.
if qt_version < 0x030000:
- sipconfig.error("TQt v2.x and earlier retquire SIP v3.x.")
+ sipconfig.error("TQt v2.x and earlier require SIP v3.x.")
if qt_version >= 0x040000:
- sipconfig.error("TQt v4.x retquires PyTQt v4.x.")
+ sipconfig.error("TQt v4.x requires PyTQt v4.x.")
# Try and work out which edition it is.
global qt_edition
@@ -1307,7 +1307,7 @@ def main(argv):
# Check SIP is new enough.
if sipcfg.sip_version_str[:8] != "snapshot":
if sipcfg.sip_version < sip_min_version:
- sipconfig.error("This version of PyTQt retquires SIP v%s or later" % sipconfig.version_to_string(sip_min_version))
+ sipconfig.error("This version of PyTQt requires SIP v%s or later" % sipconfig.version_to_string(sip_min_version))
# Parse the command line.
try:
@@ -665,7 +665,7 @@ def create_features_file(name):
"""
# The features that a given TQt configuration may or may not support. Note
- # that STYLE_WINDOWSXP and ASSISTANTCLIENT retquire special handling.
+ # that STYLE_WINDOWSXP and ASSISTANTCLIENT require special handling.
flist = ["ACTION", "CLIPBOARD", "CODECS", "COLORDIALOG", "DATASTREAM",
"DIAL", "DNS", "DOM", "DRAGANDDROP", "ICONVIEW", "IMAGE_TEXT",